==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-dev-ui-webapp/src/envelope/RuntimeToolsDevUIEnvelopeViewApi.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { DiagramPreviewSize } from "@kie-tools/runtime-tools-process-enveloped-components/dist/processDetails";
import { User } from "../api";
import { CustomLabels } from "../api/CustomLabels";

export interface RuntimeToolsDevUIEnvelopeViewApi {
  setDataIndexUrl: (dataIndexUrl: string) => void;
  setRemoteKogitoAppUrl: (remoteKogitoAppUrl: string) => void;
  setUsers: (users: User[]) => void;
  navigateTo: (page: string) => void;
  setDevUIUrl: (url: string) => void;
  setOpenApiPath: (path: string) => void;
  setProcessEnabled: (isProcessEnabled: boolean) => void;
  setAvailablePages: (availablePages: string[]) => void;
  setCustomLabels: (customLabels: CustomLabels) => void;
  setOmittedProcessTimelineEvents: (omittedProcessTimelineEvents: string[]) => void;
  setDiagramPreviewSize: (diagramPreviewSize?: DiagramPreviewSize) => void;
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-dev-ui-webapp/src/envelope/RuntimeToolsDevUIEnvelopeViewApi.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { DiagramPreviewSize } from "@kie-tools/runtime-tools-process-enveloped-components/dist/processDetails";
import { User } from "../api";
import { CustomLabels } from "../api/CustomLabels";

export interface RuntimeToolsDevUIEnvelopeViewApi {
  setDataIndexUrl: (dataIndexUrl: string) => void;
  setQuarkusAppOrigin: (quarkusAppOrigin: string) => void;
  setQuarkusAppRootPath: (quarkusAppRootPath: string) => void;
  setShouldReplaceQuarkusAppOriginWithWebappOrigin: (shouldReplaceQuarkusAppOriginWithWebappOrigin: boolean) => void;
  setUsers: (users: User[]) => void;
  navigateTo: (page: string) => void;
  setDevUIOrigin: (url: string) => void;
  setDevUIUrl: (url: string) => void;
  setProcessEnabled: (isProcessEnabled: boolean) => void;
  setAvailablePages: (availablePages: string[]) => void;
  setCustomLabels: (customLabels: CustomLabels) => void;
  setOmittedProcessTimelineEvents: (omittedProcessTimelineEvents: string[]) => void;
  setDiagramPreviewSize: (diagramPreviewSize?: DiagramPreviewSize) => void;
}
